@@ -661,7 +661,7 @@ Playground.Session = function(options) {
   $(window).resize(this._matchEditorSidebarHeight);
   this._matchEditorSidebarHeight();
 
-  $(window).unload(function(){
+  $(window).on("unload", function(){
     this.stop();
   }.bind(this));
 };
